﻿namespace HierarchicalGrid.Model
{
    using System;
    using System.Collections.Generic;
    using System.Collections.ObjectModel;
    using System.ComponentModel;
    using System.Globalization;

    public class Employee : INotifyPropertyChanged
    {
        
        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        private void NotifyPropertyChanged(String info)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(info));
            }
        }

        #endregion

        private int employId;
        private string name;
        private bool onSite;
        private int departmentId;

        public Employee()
        {
            this.ReportingEmployees = new List<Employee>();
        }

        public int EmployId
        {
            get { return this.employId; }
            set
            {
                this.employId = value;
                NotifyPropertyChanged("EmployId");
            }
        }

        public string Name
        {
            get { return this.name; }
            set
            {
                this.name = value;
                NotifyPropertyChanged("Name");
            }
        }

        public bool OnSite
        {
            get { return this.onSite; }
            set
            {
                this.onSite = value;
                NotifyPropertyChanged("OnSite");
            }
        }

        public int DepartmentId
        {
            get { return this.departmentId; }
            set
            {
                this.departmentId = value;
                NotifyPropertyChanged("DepartmentId");
            }
        }

        public List<Employee> ReportingEmployees { get; set; }
    }

    public static class Service
    {
        public static ObservableCollection<Employee> GetEmployees()
        {
            var employees = new ObservableCollection<Employee>();
            for (int i = 1; i <= 15; i++)
            {
                var employee = new Employee() { EmployId = i, Name = String.Format("Name {0}", i), DepartmentId = i % 4, OnSite = (i % 2 == 0) };
                if (i % 3 == 0)
                {
                    employee.ReportingEmployees.Add(new Employee 
                    { 
                        EmployId = i + 300,
                        Name = (i + 300).ToString(CultureInfo.InvariantCulture) + " Reporting to: " + employee.Name,
                        OnSite = employee.OnSite,
                        DepartmentId = i%3
                    });
                    employee.ReportingEmployees.Add(new Employee
                    {
                        EmployId = i + 301,
                        Name = (i + 301).ToString(CultureInfo.InvariantCulture) + " Reporting to: " + employee.Name,
                        OnSite = employee.OnSite,
                        DepartmentId = i % 3
                    });                    
                }
                employees.Add(employee);
            }
            return employees;
        }
    }
}
