﻿namespace HierarchicalGrid.ViewModel
{
    using System;
    using System.Collections.Generic;
    using System.Collections.ObjectModel;
    using System.ComponentModel;
    using System.Linq;
    using System.Text;
    using System.Threading.Tasks;

    using HierarchicalGrid.Model;

    public class MainWindowViewModel : INotifyPropertyChanged
    {
        public ObservableCollection<Employee> Employees { get; set; }

        public MainWindowViewModel()
        {
            this.Employees = new ObservableCollection<Employee>();            
            LoadData();
        }

        private void LoadData()
        {
            var context = TaskScheduler.FromCurrentSynchronizationContext();
            Task.Factory.StartNew(() =>
                {
                    if (Employees != null && Employees.Count > 0) Employees.Clear();
                    this.Employees = Service.GetEmployees();
                    this.OnPropertyChanged("Employees");
                }, 
                TaskCreationOptions.LongRunning);
        }

        #region INotifyPropertyChanged Events
        /// <summary>
        /// Property changed events to notifiy the Views that 
        /// a property has changed.
        /// </summary>          
        public event PropertyChangedEventHandler PropertyChanged;
        private void OnPropertyChanged(string propertyName)
        {
            if (this.PropertyChanged != null)
            {
                this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion
    }
}
